@@ -1,5 +1,5 @@
 
-utils::globalVariables(c("x", "y", "ct", "col_keys", "p_col", "where"))
+utils::globalVariables(c(".", "x", "y", "n", "where", "ct", "col_keys", "p_col", ".col_1", ".col_2"))
 
 #' Easily describe datasets
 #' 
@@ -15,19 +15,20 @@ utils::globalVariables(c("x", "y", "ct", "col_keys", "p_col", "where"))
 #' @param funs_arg Additional parameters for `funs`, e.g. `digits` (the number of decimal places) for the default [cross_summary()]. Ultimately, these arguments are passed to [format_fixed()].
 #' @param total one of \["none", "row", "column" or "both"] to indicate whether to add total rows and/or columns. Default to `none`.
 #' @param percent_pattern Pattern used to describe proportions in categorical data. Syntax uses a [glue::glue()] specification, see section below for more details. Default to `"{n} ({p_col})"` if `by` is null and `"{n} ({p_row})"` if it is not.
-#' @param percent_digits Number of digits for percentages
-#' @param unique_numeric The number of non-missing different levels a variable should have to be considered as numeric
-#' @param showNA Whether to show NA in categorical variables (one of \code{c("ifany", "always", "no")}, like in \code{table()})
+#' @param percent_digits Number of digits for percentages.
+#' @param num_digits Number of digits for numeric summaries.
+#' @param unique_numeric The number of non-missing different levels a variable should have to be considered as numeric.
+#' @param showNA Whether to show NA in categorical variables (one of \code{c("ifany", "always", "no")}, like in \code{table()}).
 #' @param label Whether to show labels. See [import_labels()] or [set_label()]for how to add labels to the dataset columns.
 #' @param cor_method One of `c("pearson", "kendall", "spearman")` to indicate which correlation coefficient is to be used.
-#' @param times When using formula with [survival::Surv()] objects, which times to summarize
-#' @param followup When using formula with [survival::Surv()] objects, whether to display follow-up time
-#' @param test Whether to perform tests
+#' @param times When using formula with [survival::Surv()] objects, which times to summarize.
+#' @param followup When using formula with [survival::Surv()] objects, whether to display follow-up time.
+#' @param test Whether to perform tests.
 #' @param test_args See \code{\link{crosstable_test_args}} to override default testing behaviour.
-#' @param effect Whether to compute a effect measure
+#' @param effect Whether to compute a effect measure.
 #' @param effect_args See \code{\link{crosstable_effect_args}} to override default behaviour.
 #' @param margin Deprecated in favor of `percent_pattern`. One of \["row", "column", "cell", "none", or "all"]. Default to `row`.
-#' @param .vars Deprecated
+#' @param .vars Deprecated in favor of `cols`.
 #' @inheritParams format_fixed
 #' 
 #' @section `percent_pattern`:
@@ -41,6 +42,7 @@ utils::globalVariables(c("x", "y", "ct", "col_keys", "p_col", "where"))
 #' @importFrom tidyselect vars_select eval_select everything any_of 
 #' @importFrom dplyr select mutate_if n_distinct across
 #' @importFrom purrr map map_lgl map_chr map_dfc pmap_dfr
+#' @importFrom forcats as_factor
 #' @importFrom stringr str_detect str_split
 #' @importFrom glue glue
 #' @importFrom lifecycle deprecated is_present deprecate_warn deprecate_stop
@@ -59,7 +61,7 @@ utils::globalVariables(c("x", "y", "ct", "col_keys", "p_col", "where"))
 #' #tidyselection, custom functions
 #' library(dplyr)
 #' crosstable(mtcars2, c(ends_with("t"), starts_with("c")), by=vs, 
-#'            funs=c(mean, quantile), funs_arg = list(probs=c(.25,.75)))
+#'            funs=c(mean, quantile), funs_arg=list(probs=c(.25,.75)))
 #' 
 #' #margin and totals, multiple by
 #' crosstable(mtcars2, c(disp, cyl), by=c(am, vs), 
@@ -89,7 +91,8 @@ utils::globalVariables(c("x", "y", "ct", "col_keys", "p_col", "where"))
 #'            percent_pattern="col={p_col}, row={p_row} ({ifelse(n<5, str_lo, str_high)})")
 crosstable = function(data, cols=NULL, ..., by=NULL, 
                       total = c("none", "row", "column", "both"),
-                      percent_pattern = "{n} ({p_row})", percent_digits = 2, 
+                      percent_pattern = "{n} ({p_row})", 
+                      percent_digits = 2, num_digits = 1, 
                       showNA = c("ifany", "always", "no"), label = TRUE, 
                       funs = c(" " = cross_summary), funs_arg=list(), 
                       cor_method = c("pearson", "kendall", "spearman"), 
@@ -123,7 +126,11 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
                                                  crosstable_test_args())
     if(missing(effect_args)) effect_args = getOption("crosstable_effect_args",
                                                      crosstable_effect_args())
+    if(missing(num_digits)) num_digits = getOption("crosstable_num_digits",  1)
     
+    if(!"dig" %in% names(funs_arg)){
+        funs_arg = c(funs_arg, list(dig=num_digits))
+    }
     # Arguments checks ----------------------------------------------------
     
     check_dots_unnamed()
@@ -248,8 +255,8 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
     
     duplicate_cols = intersect(byname, names(data_x))
     
-    verbose_duplicate_cols = getOption("crosstable_verbose_duplicate_cols", FALSE)
-    if(length(duplicate_cols)>0 && verbose_duplicate_cols){
+    verbosity_duplicate_cols = getOption("crosstable_verbosity_duplicate_cols", "default")
+    if(length(duplicate_cols)>0 && verbosity_duplicate_cols=="verbose"){
         warn(c("Some columns were selected in `by` and in `cols` and were removed from the latter.", 
                i=glue("Columns automatically removed from `cols`: [{x}]", 
                       x=paste(duplicate_cols, collapse=", "))), 
@@ -260,15 +267,15 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
     ncol_x = if(is.null(data_x)) 0 else ncol(data_x)
     ncol_y = if(is.null(data_y)) 0 else ncol(data_y)
     
-    # Data-management -----------------------------------------------------
+    # Unique Numerics ---------------------------------------------------------
     if(ncol_x>0){
         data_x = data_x %>% mutate(
             across(where(is.logical),
                    ~ .x %>% as.character() %>% set_label(get_label(.x))),
             across(where(~is.numeric.and.not.surv(.x) && n_distinct(.x, na.rm=TRUE)<=unique_numeric),
                    ~{
-                       .x = as.character(.x) %>% set_label(get_label(.x))
-                       class(.x) = c("unique_numeric", "character")
+                       .x = factor(.x, labels=unique(mixedsort(.x))) %>% set_label(get_label(.x))
+                       class(.x) = c("unique_numeric", class(.x))
                        .x
                    }),
         )
@@ -280,14 +287,14 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
                    ~ .x %>% as.character() %>% set_label(get_label(.x))),
             across(where(~is.numeric.and.not.surv(.x) && n_distinct(.x, na.rm=TRUE)<=unique_numeric), 
                    ~{
-                       .x = as.character(.x) %>% set_label(get_label(.x))
-                       class(.x) = c("unique_numeric", "character")
+                       .x = factor(.x, labels=unique(mixedsort(.x))) %>% set_label(get_label(.x))
+                       class(.x) = c("unique_numeric", class(.x))
                        .x
                    })
         )
     }
-    # Return checks -------------------------------------------------------
     
+    # Return checks -------------------------------------------------------
     if(ncol_x==0) {
         warn("Variable selection in crosstable ended with no variable to describe",
              class="crosstable_empty_warning")
@@ -326,7 +333,8 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
                   class="crosstable_wrong_byclass_error")
         }
         if(is.numeric(y_var)){
-            if(!identical(funs, c(` `=cross_summary)) || length(funs_arg)>0){
+            tmp=funs_arg[!names(funs_arg) %in% c("dig", "date_format")]
+            if(!identical(funs, c(` `=cross_summary)) || length(tmp)>0){
                 warn("`funs` and `funs_arg` arguments will not be used if `by` is numeric.",
                      class="crosstable_funs_by_warning")
             }
@@ -414,6 +422,7 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
         class(rtn) = c("crosstable_multiby", "crosstable", "tbl_df", "tbl", "data.frame")
         
     } else {
+        data_y2 = data_y
         rtn = cross_by(data_x=data_x, data_y=data_y, funs=funs, funs_arg=funs_arg,
                        percent_pattern=percent_pattern, percent_digits=percent_digits, 
                        total=total, showNA=showNA,
@@ -435,10 +444,12 @@ crosstable = function(data, cols=NULL, ..., by=NULL,
     if(is_null(byname) || is_empty(byname)){
         attr(rtn, "by") = NULL
         attr(rtn, "by_label") = NULL
+        attr(rtn, "by_table") = NULL
         attr(rtn, "by_levels") = NULL
     } else {
         attr(rtn, "by") = byname
         attr(rtn, "by_label") = get_label(data_y)
+        attr(rtn, "by_table") = table(data_y2)
         attr(rtn, "by_levels") = by_levels
     }
     return(rtn)
