@@ -130,7 +130,7 @@ unnamed_args = function(which=-1){
 
 # Function handling --------------------------------------------------------
 
-#' @source methods::formalArgs
+#' @source exact burgle of methods::formalArgs
 #' @keywords internal
 #' @noRd
 formalArgs = function (def){
@@ -396,25 +396,6 @@ confint_proportion = function(p, n,
     return(rtn)
 }
 
-#' Return the number of non NA observations
-#'
-#' @export
-#' @return integer, number of non NA observations
-#' @param x a vector
-#' @author David Hajage
-N = function(x) {
-    sum(!is.na(x))
-}
-
-#' Return the number of NA observations
-#'
-#' @export
-#' @return integer, number of NA observations
-#' @param x a vector
-#' @author David Hajage
-na = function(x) {
-    sum(is.na(x))
-}
 
 
 #' Small improvement around [stringr::str_wrap()] in case there is no whitespace
@@ -440,6 +421,80 @@ str_wrap2 = function(x, width, ...){
 }
 
 
+
+#' @source adapted from gtools::mixedorder() v3.9.2
+#' @keywords internal
+#' @noRd
+mixedsort = function(x, decreasing=FALSE, na.last=TRUE, blank.last=FALSE, 
+                     roman.case=c("upper", "lower", "both"), 
+                     scientific=TRUE){
+    roman.case <- match.arg(roman.case)
+    if(length(x)==0) return(NULL)
+    if(length(x)==1) return(x)
+    if(!is.character(x)) {
+        return(x[order(x, decreasing=decreasing, na.last=na.last)])
+    }
+    
+    delim <- "\\$\\@\\$"
+    if(scientific) {
+        regex <- "((?:(?i)(?:[-+]?)(?:(?=[.]?[0123456789])(?:[0123456789]*)(?:(?:[.])(?:[0123456789]{0,}))?)(?:(?:[eE])(?:(?:[-+]?)(?:[0123456789]+))|)))"
+    }
+    else {
+        regex <- "((?:(?i)(?:[-+]?)(?:(?=[.]?[0123456789])(?:[0123456789]*)(?:(?:[.])(?:[0123456789]{0,}))?)))"
+    }
+    numeric <- function(x) as.numeric(x)
+    nonnumeric <- function(x) ifelse(is.na(numeric(x)), toupper(x), NA)
+    x <- as.character(x)
+    which.nas <- which(is.na(x))
+    which.blanks <- which(x == "")
+    delimited <- gsub(regex, paste(delim, "\\1", delim, sep = ""), 
+                      x, perl = TRUE)
+    step1 <- strsplit(delimited, delim)
+    step1 <- lapply(step1, function(x) x[x > ""])
+    step1.numeric <- suppressWarnings(lapply(step1, numeric))
+    step1.character <- suppressWarnings(lapply(step1, nonnumeric))
+    maxelem <- max(sapply(step1, length))
+    step1.numeric.t <- lapply(1:maxelem, function(i) {
+        sapply(step1.numeric, function(x) x[i])
+    })
+    step1.character.t <- lapply(1:maxelem, function(i) {
+        sapply(step1.character, function(x) x[i])
+    })
+    rank.numeric <- sapply(step1.numeric.t, rank)
+    rank.character <- sapply(step1.character.t, function(x) as.numeric(factor(x)))
+    rank.numeric[!is.na(rank.character)] <- 0
+    rank.character <- t(t(rank.character) + apply(matrix(rank.numeric), 
+                                                  2, max, na.rm = TRUE))
+    rank.overall <- ifelse(is.na(rank.character), rank.numeric, 
+                           rank.character)
+    order.frame <- as.data.frame(rank.overall)
+    if(length(which.nas) > 0) {
+        if(is.na(na.last)) {
+            order.frame[which.nas, ] <- NA
+        } else if(na.last) {
+            order.frame[which.nas, ] <- Inf
+        } else {
+            order.frame[which.nas, ] <- -Inf
+        }
+    }
+    if(length(which.blanks) > 0) {
+        if(is.na(blank.last)) {
+            order.frame[which.blanks, ] <- NA
+        } else if(blank.last) {
+            order.frame[which.blanks, ] <- 1e+99
+        } else {
+            order.frame[which.blanks, ] <- -1e+99
+        }
+    }
+    order.frame <- as.list(order.frame)
+    order.frame$decreasing <- decreasing
+    order.frame$na.last <- NA
+    ord <- do.call("order", order.frame)
+    
+    x[ord]
+}
+
+
 # dplyr -------------------------------------------------------------------
 
 #' @source https://github.com/tidyverse/dplyr/issues/5563#issuecomment-721769342
